@@ -27,7 +27,8 @@ def run(args, parser):
     # Authenticate user
     if args.command == "authenticate":
         api_key = getpass.getpass(prompt="API key: ", stream=None)
-        if api_key.strip() == "":
+        api_key = api_key.strip()
+        if api_key == "":
             print(
                 "API Key needed, generate one for your team: https://darwin.v7labs.com/?settings=api-keys"
             )
@@ -44,7 +45,7 @@ def run(args, parser):
             f.list_teams()
     # Version
     elif args.command == "version":
-        print("0.3")
+        print("0.4.2")
 
     elif args.command == "dataset":
         if args.action == "remote":
